@@ -3,7 +3,7 @@ use strict;
 use warnings;
 #use warnings FATAL => 'all';
 
-our $VERSION = '0.7.1';
+our $VERSION = '0.8.0';
 
 use App::Mowyw::Lexer qw(lex);
 use App::Mowyw::Datasource;
@@ -72,16 +72,16 @@ my @input_tokens = (
             )/x                         ],
         [ 'TAG_END',        qr/\s*\]\]\]/],
         [ 'TAG_END',        qr/\s*\%\]/],
-        [ 'BRACES_START',   qr/{{/],
-        [ 'BRACES_END',     qr/}}/],
+        [ 'BRACES_START',   qr/\{\{/],
+        [ 'BRACES_END',     qr/\}\}/],
     );
 
 sub parse_all_in_dir {
     my @todo = @_;
-    while (my $fn = pop @todo){
+    while (defined(my $fn = pop @todo)){
         $fn .= '/' unless ($fn =~ m#/$#);
-        opendir DIR, $fn;
-        IW: while (my $f = readdir DIR){
+        opendir my $DIR, $fn or die "Cannot opend directory '$fn' for reading: $!";
+        IW: while (my $f = readdir $DIR){
             # ignore symbolic links and non-Readable files:
             next IW if (-l $f);
             # if we consider . and .., we loop infinetly.
@@ -91,6 +91,7 @@ sub parse_all_in_dir {
                        $f eq '..'
                     or $f eq '.'
                     or $f eq  '.svn'
+                    or $f eq  '.git'
                     or $f =~ m{(?:~|\.swp)$}){
                 next;
             }
@@ -102,7 +103,7 @@ sub parse_all_in_dir {
                 process_file($f);
             }
         }
-        closedir DIR;
+        closedir $DIR;
     }
 }
 
